from .base import Task
from .text_classification import TextClassification
from .text_generation import TextGeneration
from .qa import QA
from .summarisation import Summarisation
from .text_vectorisation import TextVectorisation
from .text_generation import TextGeneration
from .emotion import Emotion
from .image_classification import ImageClassification
from .image_vectorisation import ImageVectorisation
from .image_text_vectorisation import ImageTextVectorisation